@@ -11,19 +11,28 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 """This module configures the SageMaker Clarify bias and model explainability processor job."""
-from __future__ import print_function, absolute_import
+from __future__ import absolute_import, print_function
 
 import copy
-
-from abc import ABC, abstractmethod
 import json
+import logging
 import os
-import tempfile
 import re
-from sagemaker.processing import ProcessingInput, ProcessingOutput, Processor
+
+import tempfile
+from abc import ABC, abstractmethod
 from sagemaker import image_uris, s3, utils
+from sagemaker.deprecations import deprecation_warning
+from sagemaker.processing import ProcessingInput, ProcessingOutput, Processor
+
+logger = logging.getLogger(__name__)
 
 
+@deprecation_warning(
+    msg="s3_data_distribution_type parameter will no longer be supported. Everything else will"
+    " remain as is",
+    date="15 Mar 2022",
+)
 class DataConfig:
     """Config object related to configurations of the input and output dataset."""
 
@@ -38,6 +47,7 @@ class DataConfig:
         dataset_type="text/csv",
         s3_data_distribution_type="FullyReplicated",
         s3_compression_type="None",
+        joinsource=None,
     ):
         """Initializes a configuration of both input and output datasets.
 
@@ -54,11 +64,21 @@ class DataConfig:
                 dataset format is JSONLines.
             dataset_type (str): Format of the dataset. Valid values are "text/csv" for CSV,
                 "application/jsonlines" for JSONLines, and "application/x-parquet" for Parquet.
-            s3_data_distribution_type (str): Valid options are "FullyReplicated" or
-                "ShardedByS3Key".
+            s3_data_distribution_type (str): Deprecated. Only valid option is "FullyReplicated".
+                Any other value is ignored.
             s3_compression_type (str): Valid options are "None" or "Gzip".
+            joinsource (str): The name or index of the column in the dataset that acts as an
+                identifier column (for instance, while performing a join). This column is only
+                used as an identifier, and not used for any other computations. This is an
+                optional field in all cases except when the dataset contains more than one file,
+                and `save_local_shap_values` is set to true in SHAPConfig.
         """
-        if dataset_type not in ["text/csv", "application/jsonlines", "application/x-parquet"]:
+        if dataset_type not in [
+            "text/csv",
+            "application/jsonlines",
+            "application/x-parquet",
+            "application/x-image",
+        ]:
             raise ValueError(
                 f"Invalid dataset_type '{dataset_type}'."
                 f" Please check the API documentation for the supported dataset types."
@@ -66,7 +86,13 @@ class DataConfig:
         self.s3_data_input_path = s3_data_input_path
         self.s3_output_path = s3_output_path
         self.s3_analysis_config_output_path = s3_analysis_config_output_path
-        self.s3_data_distribution_type = s3_data_distribution_type
+        if s3_data_distribution_type != "FullyReplicated":
+            logger.warning(
+                "s3_data_distribution_type parameter, set to %s, is being ignored. Only"
+                " valid option is FullyReplicated",
+                s3_data_distribution_type,
+            )
+        self.s3_data_distribution_type = "FullyReplicated"
         self.s3_compression_type = s3_compression_type
         self.label = label
         self.headers = headers
@@ -77,6 +103,7 @@ class DataConfig:
         _set(features, "features", self.analysis_config)
         _set(headers, "headers", self.analysis_config)
         _set(label, "label", self.analysis_config)
+        _set(joinsource, "joinsource_name_or_index", self.analysis_config)
 
     def get_config(self):
         """Returns part of an analysis config dictionary."""
@@ -96,33 +123,58 @@ class BiasConfig:
         """Initializes a configuration of the sensitive groups in the dataset.
 
         Args:
-            label_values_or_threshold (Any): List of label values or threshold to indicate positive
-                outcome used for bias metrics.
-            facet_name (str or [str]): String or List of strings of sensitive attribute(s) in the
-            input data for which we like to compare metrics.
-            facet_values_or_threshold (list): Optional list of values to form a sensitive group or
-                threshold for a numeric facet column that defines the lower bound of a sensitive
-                group. Defaults to considering each possible value as sensitive group and
-                computing metrics vs all the other examples.
-                If facet_name is a list, this needs to be None or a List consisting of lists or None
-                with the same length as facet_name list.
+            label_values_or_threshold ([int or float or str]): List of label value(s) or threshold
+                to indicate positive outcome used for bias metrics. Dependency on the problem type,
+
+                * Binary problem: The list shall include one positive value.
+                * Categorical problem: The list shall include one or more (but not all) categories
+                  which are the positive values.
+                * Regression problem: The list shall include one threshold that defines the lower
+                  bound of positive values.
+
+            facet_name (str or int or [str] or [int]): Sensitive attribute column name (or index in
+                the input data) for which you like to compute bias metrics. It can also be a list
+                of names (or indexes) if you like to compute for multiple sensitive attributes.
+            facet_values_or_threshold ([int or float or str] or [[int or float or str]]):
+                The parameter indicates the sensitive group. If facet_name is a scalar, then it can
+                be None or a list. Depending on the data type of the facet column,
+
+                * Binary: None means computing the bias metrics for each binary value. Or add one
+                  binary value to the list, to compute its bias metrics only.
+                * Categorical: None means computing the bias metrics for each category. Or add one
+                  or more (but not all) categories to the list, to compute their bias metrics v.s.
+                  the other categories.
+                * Continuous: The list shall include one and only one threshold which defines the
+                  lower bound of a sensitive group.
+
+                If facet_name is a list, then it can be None if all facets are of binary type or
+                categorical type. Otherwise it shall be a list, and each element is the values or
+                threshold of the corresponding facet.
             group_name (str): Optional column name or index to indicate a group column to be used
                 for the bias metric 'Conditional Demographic Disparity in Labels - CDDL' or
                 'Conditional Demographic Disparity in Predicted Labels - CDDPL'.
         """
-        if isinstance(facet_name, str):
+        if isinstance(facet_name, list):
+            assert len(facet_name) > 0, "Please provide at least one facet"
+            if facet_values_or_threshold is None:
+                facet_list = [
+                    {"name_or_index": single_facet_name} for single_facet_name in facet_name
+                ]
+            elif len(facet_values_or_threshold) == len(facet_name):
+                facet_list = []
+                for i, single_facet_name in enumerate(facet_name):
+                    facet = {"name_or_index": single_facet_name}
+                    if facet_values_or_threshold is not None:
+                        _set(facet_values_or_threshold[i], "value_or_threshold", facet)
+                    facet_list.append(facet)
+            else:
+                raise ValueError(
+                    "The number of facet names doesn't match the number of facet values"
+                )
+        else:
             facet = {"name_or_index": facet_name}
             _set(facet_values_or_threshold, "value_or_threshold", facet)
             facet_list = [facet]
-        elif facet_values_or_threshold is None or len(facet_name) == len(facet_values_or_threshold):
-            facet_list = []
-            for i, single_facet_name in enumerate(facet_name):
-                facet = {"name_or_index": single_facet_name}
-                if facet_values_or_threshold is not None:
-                    _set(facet_values_or_threshold[i], "value_or_threshold", facet)
-                facet_list.append(facet)
-        else:
-            raise ValueError("Wrong combination of argument values passed")
         self.analysis_config = {
             "label_values_or_threshold": label_values_or_threshold,
             "facet": facet_list,
@@ -202,7 +254,14 @@ class ModelConfig:
                 )
             self.predictor_config["accept_type"] = accept_type
         if content_type is not None:
-            if content_type not in ["text/csv", "application/jsonlines"]:
+            if content_type not in [
+                "text/csv",
+                "application/jsonlines",
+                "image/jpeg",
+                "image/jpg",
+                "image/png",
+                "application/x-npy",
+            ]:
                 raise ValueError(
                     f"Invalid content_type {content_type}."
                     f" Please choose text/csv or application/jsonlines."
@@ -268,11 +327,15 @@ class ModelPredictedLabelConfig:
             probability_threshold (float): An optional value for binary prediction tasks in which
                 the model returns a probability, to indicate the threshold to convert the
                 prediction to a boolean value. Default is 0.5.
-            label_headers (list): List of label values - one for each score of the ``probability``.
+            label_headers (list[str]): List of headers, each for a predicted score in model output.
+                For bias analysis, it is used to extract the label value with the highest score as
+                predicted label. For explainability job, It is used to beautify the analysis report
+                by replacing placeholders like "label0".
         """
         self.label = label
         self.probability = probability
         self.probability_threshold = probability_threshold
+        self.label_headers = label_headers
         if probability_threshold is not None:
             try:
                 float(probability_threshold)
@@ -300,17 +363,225 @@ class ExplainabilityConfig(ABC):
         return None
 
 
+class PDPConfig(ExplainabilityConfig):
+    """Config class for Partial Dependence Plots (PDP).
+
+    If PDP is requested, the Partial Dependence Plots will be included in the report, and the
+    corresponding values will be included in the analysis output.
+    """
+
+    def __init__(self, features=None, grid_resolution=15, top_k_features=10):
+        """Initializes config for PDP.
+
+        Args:
+            features (None or list): List of features names or indices for which partial dependence
+                plots must be computed and plotted. When ShapConfig is provided, this parameter is
+                optional as Clarify will try to compute the partial dependence plots for top
+                feature based on SHAP attributions. When ShapConfig is not provided, 'features'
+                must be provided.
+            grid_resolution (int): In case of numerical features, this number represents that
+                number of buckets that range of values must be divided into. This decides the
+                granularity of the grid in which the PDP are plotted.
+            top_k_features (int): Set the number of top SHAP attributes to be selected to compute
+                partial dependence plots.
+        """
+        self.pdp_config = {"grid_resolution": grid_resolution, "top_k_features": top_k_features}
+        if features is not None:
+            self.pdp_config["features"] = features
+
+    def get_explainability_config(self):
+        """Returns config."""
+        return copy.deepcopy({"pdp": self.pdp_config})
+
+
+class TextConfig:
+    """Config object to handle text features.
+
+    The SHAP analysis will break down longer text into chunks (e.g. tokens, sentences, or paragraphs
+    ) and replace them with the strings specified in the baseline for that feature. The shap value
+    of a chunk then captures how much replacing it affects the prediction.
+    """
+
+    _SUPPORTED_GRANULARITIES = ["token", "sentence", "paragraph"]
+    _SUPPORTED_LANGUAGES = [
+        "chinese",
+        "danish",
+        "dutch",
+        "english",
+        "french",
+        "german",
+        "greek",
+        "italian",
+        "japanese",
+        "lithuanian",
+        "multi-language",
+        "norwegian bokmål",
+        "polish",
+        "portuguese",
+        "romanian",
+        "russian",
+        "spanish",
+        "afrikaans",
+        "albanian",
+        "arabic",
+        "armenian",
+        "basque",
+        "bengali",
+        "bulgarian",
+        "catalan",
+        "croatian",
+        "czech",
+        "estonian",
+        "finnish",
+        "gujarati",
+        "hebrew",
+        "hindi",
+        "hungarian",
+        "icelandic",
+        "indonesian",
+        "irish",
+        "kannada",
+        "kyrgyz",
+        "latvian",
+        "ligurian",
+        "luxembourgish",
+        "macedonian",
+        "malayalam",
+        "marathi",
+        "nepali",
+        "persian",
+        "sanskrit",
+        "serbian",
+        "setswana",
+        "sinhala",
+        "slovak",
+        "slovenian",
+        "swedish",
+        "tagalog",
+        "tamil",
+        "tatar",
+        "telugu",
+        "thai",
+        "turkish",
+        "ukrainian",
+        "urdu",
+        "vietnamese",
+        "yoruba",
+    ]
+
+    def __init__(
+        self,
+        granularity,
+        language,
+    ):
+        """Initializes a text configuration.
+
+        Args: granularity (str): Determines the granularity in which text features are broken down
+        to, can be "token", "sentence", or "paragraph". Shap values are computed for these units.
+        language (str): Specifies the language of the text features, can be "chinese", "danish",
+        "dutch", "english", "french", "german", "greek", "italian", "japanese", "lithuanian",
+        "multi-language", "norwegian bokmål", "polish", "portuguese", "romanian", "russian",
+        "spanish", "afrikaans", "albanian", "arabic", "armenian", "basque", "bengali", "bulgarian",
+        "catalan", "croatian", "czech", "estonian", "finnish", "gujarati", "hebrew", "hindi",
+        "hungarian", "icelandic", "indonesian", "irish", "kannada", "kyrgyz", "latvian", "ligurian",
+        "luxembourgish", "macedonian", "malayalam", "marathi", "nepali", "persian", "sanskrit",
+        "serbian", "setswana", "sinhala", "slovak", "slovenian", "swedish", "tagalog", "tamil",
+        "tatar", "telugu", "thai", "turkish", "ukrainian", "urdu", "vietnamese", "yoruba". Use
+        "multi-language" for a mix of mulitple languages.
+        """
+        if granularity not in TextConfig._SUPPORTED_GRANULARITIES:
+            raise ValueError(
+                f"Invalid granularity {granularity}. Please choose among "
+                f"{TextConfig._SUPPORTED_GRANULARITIES}"
+            )
+        if language not in TextConfig._SUPPORTED_LANGUAGES:
+            raise ValueError(
+                f"Invalid language {language}. Please choose among "
+                f"{TextConfig._SUPPORTED_LANGUAGES}"
+            )
+        self.text_config = {
+            "granularity": granularity,
+            "language": language,
+        }
+
+    def get_text_config(self):
+        """Returns part of an analysis config dictionary."""
+        return copy.deepcopy(self.text_config)
+
+
+class ImageConfig:
+    """Config object for handling images"""
+
+    def __init__(
+        self,
+        model_type,
+        num_segments=None,
+        feature_extraction_method=None,
+        segment_compactness=None,
+        max_objects=None,
+        iou_threshold=None,
+        context=None,
+    ):
+        """Initializes all configuration parameters needed for SHAP CV explainability
+
+        Args:
+            model_type (str): Specifies the type of CV model. Options:
+            (IMAGE_CLASSIFICATION | OBJECT_DETECTION).
+            num_segments (None or int): Clarify uses SKLearn's SLIC method for image segmentation
+            to generate features/superpixels. num_segments specifies approximate
+            number of segments to be generated. Default is None. SLIC will default to
+            100 segments.
+            feature_extraction_method (None or str): method used for extracting features from the
+            image.ex. "segmentation". Default is segmentation.
+            segment_compactness (None or float): Balances color proximity and space proximity.
+            Higher values give more weight to space proximity, making superpixel
+            shapes more square/cubic. We recommend exploring possible values on a log
+            scale, e.g., 0.01, 0.1, 1, 10, 100, before refining around a chosen value.
+            max_objects (None or int): maximum number of objects displayed. Object detection
+            algorithm may detect more than max_objects number of objects in a single
+            image. The top max_objects number of objects according to confidence score
+            will be displayed.
+            iou_threshold (None or float): minimum intersection over union for the object
+            bounding box to consider its confidence score for computing SHAP values [0.0, 1.0].
+            This parameter is used for the object detection case.
+            context (None or float): refers to the portion of the image outside of the bounding box.
+            Scale is [0.0, 1.0]. If set to 1.0, whole image is considered, if set to
+            0.0 only the image inside bounding box is considered.
+        """
+        self.image_config = {}
+
+        if model_type not in ["OBJECT_DETECTION", "IMAGE_CLASSIFICATION"]:
+            raise ValueError(
+                "Clarify SHAP only supports object detection and image classification methods. "
+                "Please set model_type to OBJECT_DETECTION or IMAGE_CLASSIFICATION."
+            )
+        self.image_config["model_type"] = model_type
+        _set(num_segments, "num_segments", self.image_config)
+        _set(feature_extraction_method, "feature_extraction_method", self.image_config)
+        _set(segment_compactness, "segment_compactness", self.image_config)
+        _set(max_objects, "max_objects", self.image_config)
+        _set(iou_threshold, "iou_threshold", self.image_config)
+        _set(context, "context", self.image_config)
+
+    def get_image_config(self):
+        """Returns the image config part of an analysis config dictionary."""
+        return copy.deepcopy(self.image_config)
+
+
 class SHAPConfig(ExplainabilityConfig):
     """Config class of SHAP."""
 
     def __init__(
         self,
-        baseline,
-        num_samples,
-        agg_method,
+        baseline=None,
+        num_samples=None,
+        agg_method=None,
         use_logit=False,
         save_local_shap_values=True,
         seed=None,
+        num_clusters=None,
+        text_config=None,
+        image_config=None,
     ):
         """Initializes config for SHAP.
 
@@ -320,34 +591,58 @@ class SHAPConfig(ExplainabilityConfig):
                 be the same as the dataset format. Each row should contain only the feature
                 columns/values and omit the label column/values. If None a baseline will be
                 calculated automatically by using K-means or K-prototypes in the input dataset.
-            num_samples (int): Number of samples to be used in the Kernel SHAP algorithm.
+            num_samples (None or int): Number of samples to be used in the Kernel SHAP algorithm.
                 This number determines the size of the generated synthetic dataset to compute the
-                SHAP values.
-            agg_method (str): Aggregation method for global SHAP values. Valid values are
+                SHAP values. If not provided then Clarify job will choose a proper value according
+                to the count of features.
+            agg_method (None or str): Aggregation method for global SHAP values. Valid values are
                 "mean_abs" (mean of absolute SHAP values for all instances),
                 "median" (median of SHAP values for all instances) and
                 "mean_sq" (mean of squared SHAP values for all instances).
+                If not provided then Clarify job uses method "mean_abs"
             use_logit (bool): Indicator of whether the logit function is to be applied to the model
                 predictions. Default is False. If "use_logit" is true then the SHAP values will
                 have log-odds units.
             save_local_shap_values (bool): Indicator of whether to save the local SHAP values
                 in the output location. Default is True.
             seed (int): seed value to get deterministic SHAP values. Default is None.
+            num_clusters (None or int): If a baseline is not provided, Clarify automatically
+                computes a baseline dataset via a clustering algorithm (K-means/K-prototypes).
+                num_clusters is a parameter for this algorithm. num_clusters will be the resulting
+                size of the baseline dataset. If not provided, Clarify job will use a default value.
+            text_config (:class:`~sagemaker.clarify.TextConfig`): Config to handle text features.
+                Default is None
+            image_config (:class:`~sagemaker.clarify.ImageConfig`): Config to handle image features.
+                Default is None
         """
-        if agg_method not in ["mean_abs", "median", "mean_sq"]:
+        if agg_method is not None and agg_method not in ["mean_abs", "median", "mean_sq"]:
             raise ValueError(
                 f"Invalid agg_method {agg_method}." f" Please choose mean_abs, median, or mean_sq."
             )
-
+        if num_clusters is not None and baseline is not None:
+            raise ValueError(
+                "Baseline and num_clusters cannot be provided together. "
+                "Please specify one of the two."
+            )
         self.shap_config = {
-            "baseline": baseline,
-            "num_samples": num_samples,
-            "agg_method": agg_method,
             "use_logit": use_logit,
             "save_local_shap_values": save_local_shap_values,
         }
-        if seed is not None:
-            self.shap_config["seed"] = seed
+        _set(baseline, "baseline", self.shap_config)
+        _set(num_samples, "num_samples", self.shap_config)
+        _set(agg_method, "agg_method", self.shap_config)
+        _set(seed, "seed", self.shap_config)
+        _set(num_clusters, "num_clusters", self.shap_config)
+        if text_config:
+            _set(text_config.get_text_config(), "text_config", self.shap_config)
+            if not save_local_shap_values:
+                logger.warning(
+                    "Global aggregation is not yet supported for text features. "
+                    "Consider setting save_local_shap_values=True to inspect local text "
+                    "explanations."
+                )
+        if image_config:
+            _set(image_config.get_image_config(), "image_config", self.shap_config)
 
     def get_explainability_config(self):
         """Returns config."""
@@ -471,7 +766,10 @@ class SageMakerClarifyProcessor(Processor):
                 will be unassociated.
                 * `TrialComponentDisplayName` is used for display in Studio.
         """
-        analysis_config["methods"]["report"] = {"name": "report", "title": "Analysis Report"}
+        analysis_config["methods"]["report"] = {
+            "name": "report",
+            "title": "Analysis Report",
+        }
         with tempfile.TemporaryDirectory() as tmpdirname:
             analysis_config_file = os.path.join(tmpdirname, "analysis_config.json")
             with open(analysis_config_file, "w") as f:
@@ -573,7 +871,15 @@ class SageMakerClarifyProcessor(Processor):
                 job_name = utils.name_from_base(self.job_name_prefix)
             else:
                 job_name = utils.name_from_base("Clarify-Pretraining-Bias")
-        self._run(data_config, analysis_config, wait, logs, job_name, kms_key, experiment_config)
+        self._run(
+            data_config,
+            analysis_config,
+            wait,
+            logs,
+            job_name,
+            kms_key,
+            experiment_config,
+        )
 
     def run_post_training_bias(
         self,
@@ -651,7 +957,15 @@ class SageMakerClarifyProcessor(Processor):
                 job_name = utils.name_from_base(self.job_name_prefix)
             else:
                 job_name = utils.name_from_base("Clarify-Posttraining-Bias")
-        self._run(data_config, analysis_config, wait, logs, job_name, kms_key, experiment_config)
+        self._run(
+            data_config,
+            analysis_config,
+            wait,
+            logs,
+            job_name,
+            kms_key,
+            experiment_config,
+        )
 
     def run_bias(
         self,
@@ -746,7 +1060,15 @@ class SageMakerClarifyProcessor(Processor):
                 job_name = utils.name_from_base(self.job_name_prefix)
             else:
                 job_name = utils.name_from_base("Clarify-Bias")
-        self._run(data_config, analysis_config, wait, logs, job_name, kms_key, experiment_config)
+        self._run(
+            data_config,
+            analysis_config,
+            wait,
+            logs,
+            job_name,
+            kms_key,
+            experiment_config,
+        )
 
     def run_explainability(
         self,
@@ -776,12 +1098,13 @@ class SageMakerClarifyProcessor(Processor):
             data_config (:class:`~sagemaker.clarify.DataConfig`): Config of the input/output data.
             model_config (:class:`~sagemaker.clarify.ModelConfig`): Config of the model and its
                 endpoint to be created.
-            explainability_config (:class:`~sagemaker.clarify.ExplainabilityConfig`): Config of the
-                specific explainability method. Currently, only SHAP is supported.
-            model_scores(str|int|ModelPredictedLabelConfig):  Index or JSONPath location in the
-                model output for the predicted scores to be explained. This is not required if the
-                model output is a single score. Alternatively, an instance of
-                ModelPredictedLabelConfig can be provided.
+            explainability_config (:class:`~sagemaker.clarify.ExplainabilityConfig` or list):
+                Config of the specific explainability method or a list of ExplainabilityConfig
+                objects. Currently, SHAP and PDP are the two methods supported.
+            model_scores (int or str or :class:`~sagemaker.clarify.ModelPredictedLabelConfig`):
+                Index or JSONPath to locate the predicted scores in the model output. This is not
+                required if the model output is a single score. Alternatively, it can be an instance
+                of ModelPredictedLabelConfig to provide more parameters like label_headers.
             wait (bool): Whether the call should wait until the job completes (default: True).
             logs (bool): Whether to show the logs produced by the job.
                 Only meaningful when ``wait`` is True (default: True).
@@ -806,19 +1129,53 @@ class SageMakerClarifyProcessor(Processor):
         analysis_config = data_config.get_config()
         predictor_config = model_config.get_predictor_config()
         if isinstance(model_scores, ModelPredictedLabelConfig):
-            probability_threshold, predicted_label_config = model_scores.get_predictor_config()
+            (
+                probability_threshold,
+                predicted_label_config,
+            ) = model_scores.get_predictor_config()
             _set(probability_threshold, "probability_threshold", analysis_config)
             predictor_config.update(predicted_label_config)
         else:
             _set(model_scores, "label", predictor_config)
-        analysis_config["methods"] = explainability_config.get_explainability_config()
+
+        explainability_methods = {}
+        if isinstance(explainability_config, list):
+            if len(explainability_config) == 0:
+                raise ValueError("Please provide at least one explainability config.")
+            for config in explainability_config:
+                explain_config = config.get_explainability_config()
+                explainability_methods.update(explain_config)
+            if not len(explainability_methods.keys()) == len(explainability_config):
+                raise ValueError("Duplicate explainability configs are provided")
+            if (
+                "shap" not in explainability_methods
+                and explainability_methods["pdp"].get("features", None) is None
+            ):
+                raise ValueError("PDP features must be provided when ShapConfig is not provided")
+        else:
+            if (
+                isinstance(explainability_config, PDPConfig)
+                and explainability_config.get_explainability_config()["pdp"].get("features", None)
+                is None
+            ):
+                raise ValueError("PDP features must be provided when ShapConfig is not provided")
+            explainability_methods = explainability_config.get_explainability_config()
+        analysis_config["methods"] = explainability_methods
         analysis_config["predictor"] = predictor_config
         if job_name is None:
             if self.job_name_prefix:
                 job_name = utils.name_from_base(self.job_name_prefix)
             else:
                 job_name = utils.name_from_base("Clarify-Explainability")
-        self._run(data_config, analysis_config, wait, logs, job_name, kms_key, experiment_config)
+        self._run(
+            data_config,
+            analysis_config,
+            wait,
+            logs,
+            job_name,
+            kms_key,
+            experiment_config,
+        )
 
 
 def _upload_analysis_config(analysis_config_file, s3_output_path, sagemaker_session, kms_key):
