@@ -74,6 +74,8 @@ class RegisterModel(StepCollection):
         description=None,
         tags=None,
         model: Union[Model, PipelineModel] = None,
+        drift_check_baselines=None,
+        customer_metadata_properties=None,
         **kwargs,
     ):
         """Construct steps `_RepackModelStep` and `_RegisterModelStep` based on the estimator.
@@ -94,7 +96,7 @@ class RegisterModel(StepCollection):
                 for the repack model step
             register_model_step_retry_policies (List[RetryPolicy]): The list of retry policies
                 for register model step
-            model_package_group_name (str): The Model Package Group name, exclusive to
+            model_package_group_name (str): The Model Package Group name or Arn, exclusive to
                 `model_package_name`, using `model_package_group_name` makes the Model Package
                 versioned (default: None).
             model_metrics (ModelMetrics): ModelMetrics object (default: None).
@@ -111,6 +113,10 @@ class RegisterModel(StepCollection):
                 tags will not be applied.
             model (object or Model): A PipelineModel object that comprises a list of models
                 which gets executed as a serial inference pipeline or a Model object.
+            drift_check_baselines (DriftCheckBaselines): DriftCheckBaselines object (default: None).
+            customer_metadata_properties (dict[str, str]): A dictionary of key-value paired
+                metadata properties (default: None).
+
             **kwargs: additional arguments to `create_model`.
         """
         steps: List[Step] = []
@@ -218,6 +224,7 @@ class RegisterModel(StepCollection):
             transform_instances=transform_instances,
             model_package_group_name=model_package_group_name,
             model_metrics=model_metrics,
+            drift_check_baselines=drift_check_baselines,
             approval_status=approval_status,
             image_uri=image_uri,
             compile_model_family=compile_model_family,
@@ -226,6 +233,7 @@ class RegisterModel(StepCollection):
             tags=tags,
             container_def_list=self.container_def_list,
             retry_policies=register_model_step_retry_policies,
+            customer_metadata_properties=customer_metadata_properties,
             **kwargs,
         )
         if not repack_model:
@@ -315,15 +323,15 @@ class EstimatorTransformer(StepCollection):
         """
         steps = []
         if "entry_point" in kwargs:
-            entry_point = kwargs["entry_point"]
-            source_dir = kwargs.get("source_dir")
-            dependencies = kwargs.get("dependencies")
+            entry_point = kwargs.get("entry_point", None)
+            source_dir = kwargs.get("source_dir", None)
+            dependencies = kwargs.get("dependencies", None)
             repack_model_step = _RepackModelStep(
                 name=f"{name}RepackModel",
                 depends_on=depends_on,
                 retry_policies=repack_model_step_retry_policies,
                 sagemaker_session=estimator.sagemaker_session,
-                role=estimator.sagemaker_session,
+                role=estimator.role,
                 model_data=model_data,
                 entry_point=entry_point,
                 source_dir=source_dir,
@@ -349,7 +357,11 @@ class EstimatorTransformer(StepCollection):
             vpc_config=None,
             sagemaker_session=estimator.sagemaker_session,
             role=estimator.role,
-            **kwargs,
+            env=kwargs.get("env", None),
+            name=kwargs.get("name", None),
+            enable_network_isolation=kwargs.get("enable_network_isolation", None),
+            model_kms_key=kwargs.get("model_kms_key", None),
+            image_config=kwargs.get("image_config", None),
         )
         model_step = CreateModelStep(
             name=f"{name}CreateModelStep",
