@@ -10,19 +10,22 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""The step definitions for workflow."""
+"""The `Step` definitions for SageMaker Pipelines Workflows."""
 from __future__ import absolute_import
 
 import abc
+import warnings
 
 from enum import Enum
 from typing import Dict, List, Union
+from urllib.parse import urlparse
 
 import attr
 
 from sagemaker.estimator import EstimatorBase, _TrainingJob
 from sagemaker.inputs import CreateModelInput, TrainingInput, TransformInput, FileSystemInput
 from sagemaker.model import Model
+from sagemaker.pipeline import PipelineModel
 from sagemaker.processing import (
     ProcessingInput,
     ProcessingJob,
@@ -45,7 +48,7 @@ from sagemaker.workflow.retry import RetryPolicy
 
 
 class StepTypeEnum(Enum, metaclass=DefaultEnumMeta):
-    """Enum of step types."""
+    """Enum of `Step` types."""
 
     CONDITION = "Condition"
     CREATE_MODEL = "Model"
@@ -56,20 +59,24 @@ class StepTypeEnum(Enum, metaclass=DefaultEnumMeta):
     CALLBACK = "Callback"
     TUNING = "Tuning"
     LAMBDA = "Lambda"
+    QUALITY_CHECK = "QualityCheck"
+    CLARIFY_CHECK = "ClarifyCheck"
+    EMR = "EMR"
+    FAIL = "Fail"
 
 
 @attr.s
 class Step(Entity):
-    """Pipeline step for workflow.
+    """Pipeline `Step` for SageMaker Pipelines Workflows.
 
     Attributes:
-        name (str): The name of the step.
-        display_name (str): The display name of the step.
-        description (str): The description of the step.
-        step_type (StepTypeEnum): The type of the step.
-        depends_on (List[str] or List[Step]): The list of step names or step
-            instances the current step depends on
-        retry_policies (List[RetryPolicy]): The custom retry policy configuration
+        name (str): The name of the `Step`.
+        display_name (str): The display name of the `Step`.
+        description (str): The description of the `Step`.
+        step_type (StepTypeEnum): The type of the `Step`.
+        depends_on (List[str] or List[Step]): The list of `Step` names or `Step`
+            instances that the current `Step` depends on.
+        retry_policies (List[RetryPolicy]): The custom retry policy configuration.
     """
 
     name: str = attr.ib(factory=str)
@@ -81,12 +88,12 @@ class Step(Entity):
     @property
     @abc.abstractmethod
     def arguments(self) -> RequestType:
-        """The arguments to the particular step service call."""
+        """The arguments to the particular `Step` service call."""
 
     @property
     @abc.abstractmethod
     def properties(self):
-        """The properties of the particular step."""
+        """The properties of the particular `Step`."""
 
     def to_request(self) -> RequestType:
         """Gets the request structure for workflow service calls."""
@@ -105,7 +112,7 @@ class Step(Entity):
         return request_dict
 
     def add_depends_on(self, step_names: Union[List[str], List["Step"]]):
-        """Add step names or step instances to the current step depends on list"""
+        """Add `Step` names or `Step` instances to the current `Step` depends on list."""
 
         if not step_names:
             return
@@ -116,12 +123,12 @@ class Step(Entity):
 
     @property
     def ref(self) -> Dict[str, str]:
-        """Gets a reference dict for steps"""
+        """Gets a reference dictionary for `Step` instances."""
         return {"Name": self.name}
 
     @staticmethod
     def _resolve_depends_on(depends_on_list: Union[List[str], List["Step"]]) -> List[str]:
-        """Resolve the step depends on list"""
+        """Resolve the `Step` depends on list."""
         depends_on = []
         for step in depends_on_list:
             if isinstance(step, Step):
@@ -135,18 +142,19 @@ class Step(Entity):
 
 @attr.s
 class CacheConfig:
-    """Configuration class to enable caching in pipeline workflow.
+    """Configuration class to enable caching in SageMaker Pipelines Workflows.
 
-    If caching is enabled, the pipeline attempts to find a previous execution of a step
-    that was called with the same arguments. Step caching only considers successful execution.
+    If caching is enabled, the pipeline attempts to find a previous execution of a `Step`
+    that was called with the same arguments. `Step` caching only considers successful execution.
     If a successful previous execution is found, the pipeline propagates the values
-    from previous execution rather than recomputing the step. When multiple successful executions
-    exist within the timeout period, it uses the result for the most recent successful execution.
+    from the previous execution rather than recomputing the `Step`.
+    When multiple successful executions exist within the timeout period,
+    it uses the result for the most recent successful execution.
 
 
     Attributes:
-        enable_caching (bool): To enable step caching. Defaults to `False`.
-        expire_after (str): If step caching is enabled, a timeout also needs to defined.
+        enable_caching (bool): To enable `Step` caching. Defaults to `False`.
+        expire_after (str): If `Step` caching is enabled, a timeout also needs to defined.
             It defines how old a previous execution can be to be considered for reuse.
             Value should be an ISO 8601 duration string. Defaults to `None`.
 
@@ -164,7 +172,7 @@ class CacheConfig:
 
     @property
     def config(self):
-        """Configures caching in pipeline steps."""
+        """Configures `Step` caching for SageMaker Pipelines Workflows."""
         config = {"Enabled": self.enable_caching}
         if self.expire_after is not None:
             config["ExpireAfter"] = self.expire_after
@@ -172,7 +180,7 @@ class CacheConfig:
 
 
 class ConfigurableRetryStep(Step):
-    """ConfigurableRetryStep step for workflow."""
+    """`ConfigurableRetryStep` for SageMaker Pipelines Workflows."""
 
     def __init__(
         self,
@@ -193,7 +201,7 @@ class ConfigurableRetryStep(Step):
         self.retry_policies = [] if not retry_policies else retry_policies
 
     def add_retry_policy(self, retry_policy: RetryPolicy):
-        """Add a retry policy to the current step retry policies list."""
+        """Add a policy to the current `ConfigurableRetryStep` retry policies list."""
         if not retry_policy:
             return
 
@@ -202,7 +210,7 @@ class ConfigurableRetryStep(Step):
         self.retry_policies.append(retry_policy)
 
     def to_request(self) -> RequestType:
-        """Gets the request structure for ConfigurableRetryStep"""
+        """Gets the request structure for `ConfigurableRetryStep`."""
         step_dict = super().to_request()
         if self.retry_policies:
             step_dict["RetryPolicies"] = self._resolve_retry_policy(self.retry_policies)
@@ -210,12 +218,12 @@ class ConfigurableRetryStep(Step):
 
     @staticmethod
     def _resolve_retry_policy(retry_policy_list: List[RetryPolicy]) -> List[RequestType]:
-        """Resolve the step retry policy list"""
+        """Resolve the `ConfigurableRetryStep` retry policy list."""
         return [retry_policy.to_request() for retry_policy in retry_policy_list]
 
 
 class TrainingStep(ConfigurableRetryStep):
-    """Training step for workflow."""
+    """`TrainingStep` for SageMaker Pipelines Workflows."""
 
     def __init__(
         self,
@@ -228,23 +236,23 @@ class TrainingStep(ConfigurableRetryStep):
         depends_on: Union[List[str], List[Step]] = None,
         retry_policies: List[RetryPolicy] = None,
     ):
-        """Construct a TrainingStep, given an `EstimatorBase` instance.
+        """Construct a `TrainingStep`, given an `EstimatorBase` instance.
 
-        In addition to the estimator instance, the other arguments are those that are supplied to
-        the `fit` method of the `sagemaker.estimator.Estimator`.
+        In addition to the `EstimatorBase` instance, the other arguments are those
+        that are supplied to the `fit` method of the `sagemaker.estimator.Estimator`.
 
         Args:
-            name (str): The name of the training step.
+            name (str): The name of the `TrainingStep`.
             estimator (EstimatorBase): A `sagemaker.estimator.EstimatorBase` instance.
-            display_name (str): The display name of the training step.
-            description (str): The description of the training step.
+            display_name (str): The display name of the `TrainingStep`.
+            description (str): The description of the `TrainingStep`.
             inputs (Union[str, dict, TrainingInput, FileSystemInput]): Information
                 about the training data. This can be one of three types:
 
                 * (str) the S3 location where training data is saved, or a file:// path in
                   local mode.
                 * (dict[str, str] or dict[str, sagemaker.inputs.TrainingInput]) If using multiple
-                  channels for training data, you can specify a dict mapping channel names to
+                  channels for training data, you can specify a dictionary mapping channel names to
                   strings or :func:`~sagemaker.inputs.TrainingInput` objects.
                 * (sagemaker.inputs.TrainingInput) - channel configuration for S3 data sources
                   that can provide additional information as well as the path to the training
@@ -255,9 +263,9 @@ class TrainingStep(ConfigurableRetryStep):
                   the path to the training dataset.
 
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
-            depends_on (List[str] or List[Step]): A list of step names or step instances
-                this `sagemaker.workflow.steps.TrainingStep` depends on
-            retry_policies (List[RetryPolicy]):  A list of retry policy
+            depends_on (List[str] or List[Step]): A list of `Step` names or `Step` instances
+                this `sagemaker.workflow.steps.TrainingStep` depends on.
+            retry_policies (List[RetryPolicy]):  A list of retry policies.
         """
         super(TrainingStep, self).__init__(
             name, StepTypeEnum.TRAINING, display_name, description, depends_on, retry_policies
@@ -269,12 +277,22 @@ class TrainingStep(ConfigurableRetryStep):
         )
         self.cache_config = cache_config
 
+        if self.cache_config is not None and not self.estimator.disable_profiler:
+            msg = (
+                "Profiling is enabled on the provided estimator. "
+                "The default profiler rule includes a timestamp "
+                "which will change each time the pipeline is "
+                "upserted, causing cache misses. If profiling "
+                "is not needed, set disable_profiler to True on the estimator."
+            )
+            warnings.warn(msg)
+
     @property
     def arguments(self) -> RequestType:
-        """The arguments dict that is used to call `create_training_job`.
+        """The arguments dictionary that is used to call `create_training_job`.
 
-        NOTE: The CreateTrainingJob request is not quite the args list that workflow needs.
-        The TrainingJobName and ExperimentConfig attributes cannot be included.
+        NOTE: The `CreateTrainingJob` request is not quite the args list that workflow needs.
+        The `TrainingJobName` and `ExperimentConfig` attributes cannot be included.
         """
 
         self.estimator._prepare_for_training()
@@ -283,16 +301,18 @@ class TrainingStep(ConfigurableRetryStep):
         )
         request_dict = self.estimator.sagemaker_session._get_train_request(**train_args)
         request_dict.pop("TrainingJobName")
+        if "HyperParameters" in request_dict:
+            request_dict["HyperParameters"].pop("sagemaker_job_name", None)
 
         return request_dict
 
     @property
     def properties(self):
-        """A Properties object representing the DescribeTrainingJobResponse data model."""
+        """A `Properties` object representing the `DescribeTrainingJobResponse` data model."""
         return self._properties
 
     def to_request(self) -> RequestType:
-        """Updates the dictionary with cache configuration."""
+        """Updates the request dictionary with cache configuration."""
         request_dict = super().to_request()
         if self.cache_config:
             request_dict.update(self.cache_config.config)
@@ -301,33 +321,34 @@ class TrainingStep(ConfigurableRetryStep):
 
 
 class CreateModelStep(ConfigurableRetryStep):
-    """CreateModel step for workflow."""
+    """`CreateModelStep` for SageMaker Pipelines Workflows."""
 
     def __init__(
         self,
         name: str,
-        model: Model,
+        model: Union[Model, PipelineModel],
         inputs: CreateModelInput,
         depends_on: Union[List[str], List[Step]] = None,
         retry_policies: List[RetryPolicy] = None,
         display_name: str = None,
         description: str = None,
     ):
-        """Construct a CreateModelStep, given an `sagemaker.model.Model` instance.
+        """Construct a `CreateModelStep`, given an `sagemaker.model.Model` instance.
 
-        In addition to the Model instance, the other arguments are those that are supplied to
+        In addition to the `Model` instance, the other arguments are those that are supplied to
         the `_create_sagemaker_model` method of the `sagemaker.model.Model._create_sagemaker_model`.
 
         Args:
-            name (str): The name of the CreateModel step.
-            model (Model): A `sagemaker.model.Model` instance.
+            name (str): The name of the `CreateModelStep`.
+            model (Model or PipelineModel): A `sagemaker.model.Model`
+                or `sagemaker.pipeline.PipelineModel` instance.
             inputs (CreateModelInput): A `sagemaker.inputs.CreateModelInput` instance.
                 Defaults to `None`.
-            depends_on (List[str] or List[Step]): A list of step names or step instances
-                this `sagemaker.workflow.steps.CreateModelStep` depends on
-            retry_policies (List[RetryPolicy]):  A list of retry policy
-            display_name (str): The display name of the CreateModel step.
-            description (str): The description of the CreateModel step.
+            depends_on (List[str] or List[Step]): A list of `Step` names or `Step` instances
+                this `sagemaker.workflow.steps.CreateModelStep` depends on.
+            retry_policies (List[RetryPolicy]):  A list of retry policies.
+            display_name (str): The display name of the `CreateModelStep`.
+            description (str): The description of the `CreateModelStep`.
         """
         super(CreateModelStep, self).__init__(
             name, StepTypeEnum.CREATE_MODEL, display_name, description, depends_on, retry_policies
@@ -339,34 +360,43 @@ class CreateModelStep(ConfigurableRetryStep):
 
     @property
     def arguments(self) -> RequestType:
-        """The arguments dict that is used to call `create_model`.
+        """The arguments dictionary that is used to call `create_model`.
 
-        NOTE: The CreateModelRequest is not quite the args list that workflow needs.
-        ModelName cannot be included in the arguments.
+        NOTE: The `CreateModelRequest` is not quite the args list that workflow needs.
+        `ModelName` cannot be included in the arguments.
         """
 
-        request_dict = self.model.sagemaker_session._create_model_request(
-            name="",
-            role=self.model.role,
-            container_defs=self.model.prepare_container_def(
-                instance_type=self.inputs.instance_type,
-                accelerator_type=self.inputs.accelerator_type,
-            ),
-            vpc_config=self.model.vpc_config,
-            enable_network_isolation=self.model.enable_network_isolation(),
-        )
+        if isinstance(self.model, PipelineModel):
+            request_dict = self.model.sagemaker_session._create_model_request(
+                name="",
+                role=self.model.role,
+                container_defs=self.model.pipeline_container_def(self.inputs.instance_type),
+                vpc_config=self.model.vpc_config,
+                enable_network_isolation=self.model.enable_network_isolation,
+            )
+        else:
+            request_dict = self.model.sagemaker_session._create_model_request(
+                name="",
+                role=self.model.role,
+                container_defs=self.model.prepare_container_def(
+                    instance_type=self.inputs.instance_type,
+                    accelerator_type=self.inputs.accelerator_type,
+                ),
+                vpc_config=self.model.vpc_config,
+                enable_network_isolation=self.model.enable_network_isolation(),
+            )
         request_dict.pop("ModelName")
 
         return request_dict
 
     @property
     def properties(self):
-        """A Properties object representing the DescribeModelResponse data model."""
+        """A `Properties` object representing the `DescribeModelResponse` data model."""
         return self._properties
 
 
 class TransformStep(ConfigurableRetryStep):
-    """Transform step for workflow."""
+    """`TransformStep` for SageMaker Pipelines Workflows."""
 
     def __init__(
         self,
@@ -379,21 +409,21 @@ class TransformStep(ConfigurableRetryStep):
         depends_on: Union[List[str], List[Step]] = None,
         retry_policies: List[RetryPolicy] = None,
     ):
-        """Constructs a TransformStep, given an `Transformer` instance.
+        """Constructs a `TransformStep`, given a `Transformer` instance.
 
-        In addition to the transformer instance, the other arguments are those that are supplied to
-        the `transform` method of the `sagemaker.transformer.Transformer`.
+        In addition to the `Transformer` instance, the other arguments are those
+        that are supplied to the `transform` method of the `sagemaker.transformer.Transformer`.
 
         Args:
-            name (str): The name of the transform step.
+            name (str): The name of the `TransformStep`.
             transformer (Transformer): A `sagemaker.transformer.Transformer` instance.
             inputs (TransformInput): A `sagemaker.inputs.TransformInput` instance.
-            cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
-            display_name (str): The display name of the transform step.
-            description (str): The description of the transform step.
-            depends_on (List[str]): A list of step names this `sagemaker.workflow.steps.TransformStep`
-                depends on
-            retry_policies (List[RetryPolicy]):  A list of retry policy
+            cache_config (CacheConfig): A `sagemaker.workflow.steps.CacheConfig` instance.
+            display_name (str): The display name of the `TransformStep`.
+            description (str): The description of the `TransformStep`.
+            depends_on (List[str]): A list of `Step` names that this `sagemaker.workflow.steps.TransformStep`
+                depends on.
+            retry_policies (List[RetryPolicy]): A list of retry policies.
         """
         super(TransformStep, self).__init__(
             name, StepTypeEnum.TRANSFORM, display_name, description, depends_on, retry_policies
@@ -407,10 +437,10 @@ class TransformStep(ConfigurableRetryStep):
 
     @property
     def arguments(self) -> RequestType:
-        """The arguments dict that is used to call `create_transform_job`.
+        """The arguments dictionary that is used to call `create_transform_job`.
 
-        NOTE: The CreateTransformJob request is not quite the args list that workflow needs.
-        TransformJobName and ExperimentConfig cannot be included in the arguments.
+        NOTE: The `CreateTransformJob` request is not quite the args list that workflow needs.
+        `TransformJobName` and `ExperimentConfig` cannot be included in the arguments.
         """
         transform_args = _TransformJob._get_transform_args(
             transformer=self.transformer,
@@ -433,7 +463,7 @@ class TransformStep(ConfigurableRetryStep):
 
     @property
     def properties(self):
-        """A Properties object representing the DescribeTransformJobResponse data model."""
+        """A `Properties` object representing the `DescribeTransformJobResponse` data model."""
         return self._properties
 
     def to_request(self) -> RequestType:
@@ -446,7 +476,7 @@ class TransformStep(ConfigurableRetryStep):
 
 
 class ProcessingStep(ConfigurableRetryStep):
-    """Processing step for workflow."""
+    """`ProcessingStep` for SageMaker Pipelines Workflows."""
 
     def __init__(
         self,
@@ -462,17 +492,18 @@ class ProcessingStep(ConfigurableRetryStep):
         cache_config: CacheConfig = None,
         depends_on: Union[List[str], List[Step]] = None,
         retry_policies: List[RetryPolicy] = None,
+        kms_key=None,
     ):
-        """Construct a ProcessingStep, given a `Processor` instance.
+        """Construct a `ProcessingStep`, given a `Processor` instance.
 
-        In addition to the processor instance, the other arguments are those that are supplied to
+        In addition to the `Processor` instance, the other arguments are those that are supplied to
         the `process` method of the `sagemaker.processing.Processor`.
 
         Args:
-            name (str): The name of the processing step.
+            name (str): The name of the `ProcessingStep`.
             processor (Processor): A `sagemaker.processing.Processor` instance.
-            display_name (str): The display name of the processing step.
-            description (str): The description of the processing step.
+            display_name (str): The display name of the `ProcessingStep`.
+            description (str): The description of the `ProcessingStep`
             inputs (List[ProcessingInput]): A list of `sagemaker.processing.ProcessorInput`
                 instances. Defaults to `None`.
             outputs (List[ProcessingOutput]): A list of `sagemaker.processing.ProcessorOutput`
@@ -484,9 +515,11 @@ class ProcessingStep(ConfigurableRetryStep):
             property_files (List[PropertyFile]): A list of property files that workflow looks
                 for and resolves from the configured processing output list.
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
-            depends_on (List[str] or List[Step]): A list of step names or step instance
-                this `sagemaker.workflow.steps.ProcessingStep` depends on
-            retry_policies (List[RetryPolicy]):  A list of retry policy
+            depends_on (List[str] or List[Step]): A list of `Step` names or `Step` instances that
+                this `sagemaker.workflow.steps.ProcessingStep` depends on.
+            retry_policies (List[RetryPolicy]):  A list of retry policies.
+            kms_key (str): The ARN of the KMS key that is used to encrypt the
+                user code file. Defaults to `None`.
         """
         super(ProcessingStep, self).__init__(
             name, StepTypeEnum.PROCESSING, display_name, description, depends_on, retry_policies
@@ -497,9 +530,11 @@ class ProcessingStep(ConfigurableRetryStep):
         self.job_arguments = job_arguments
         self.code = code
         self.property_files = property_files
+        self.job_name = None
+        self.kms_key = kms_key
 
-        # Examine why run method in sagemaker.processing.Processor mutates the processor instance
-        # by setting the instance's arguments attribute. Refactor Processor.run, if possible.
+        # Examine why run method in `sagemaker.processing.Processor` mutates the processor instance
+        # by setting the instance's arguments attribute. Refactor `Processor.run`, if possible.
         self.processor.arguments = job_arguments
 
         self._properties = Properties(
@@ -507,20 +542,32 @@ class ProcessingStep(ConfigurableRetryStep):
         )
         self.cache_config = cache_config
 
+        if code:
+            code_url = urlparse(code)
+            if code_url.scheme == "" or code_url.scheme == "file":
+                # By default, `Processor` will upload the local code to an S3 path
+                # containing a timestamp. This causes cache misses whenever a
+                # pipeline is updated, even if the underlying script hasn't changed.
+                # To avoid this, hash the contents of the script and include it
+                # in the `job_name` passed to the `Processor`, which will be used
+                # instead of the timestamped path.
+                self.job_name = self._generate_code_upload_path()
+
     @property
     def arguments(self) -> RequestType:
-        """The arguments dict that is used to call `create_processing_job`.
+        """The arguments dictionary that is used to call `create_processing_job`.
 
-        NOTE: The CreateProcessingJob request is not quite the args list that workflow needs.
-        ProcessingJobName and ExperimentConfig cannot be included in the arguments.
+        NOTE: The `CreateProcessingJob` request is not quite the args list that workflow needs.
+        `ProcessingJobName` and `ExperimentConfig` cannot be included in the arguments.
         """
         normalized_inputs, normalized_outputs = self.processor._normalize_args(
+            job_name=self.job_name,
             arguments=self.job_arguments,
             inputs=self.inputs,
             outputs=self.outputs,
             code=self.code,
+            kms_key=self.kms_key,
         )
-
         process_args = ProcessingJob._get_process_args(
             self.processor, normalized_inputs, normalized_outputs, experiment_config=dict()
         )
@@ -531,7 +578,7 @@ class ProcessingStep(ConfigurableRetryStep):
 
     @property
     def properties(self):
-        """A Properties object representing the DescribeProcessingJobResponse data model."""
+        """A `Properties` object representing the `DescribeProcessingJobResponse` data model."""
         return self._properties
 
     def to_request(self) -> RequestType:
@@ -545,9 +592,16 @@ class ProcessingStep(ConfigurableRetryStep):
             ]
         return request_dict
 
+    def _generate_code_upload_path(self) -> str:
+        """Generate an upload path for local processing scripts based on its contents."""
+        from sagemaker.workflow.utilities import hash_file
+
+        code_hash = hash_file(self.code)
+        return f"{self.name}-{code_hash}"[:1024]
+
 
 class TuningStep(ConfigurableRetryStep):
-    """Tuning step for workflow."""
+    """`TuningStep` for SageMaker Pipelines Workflows."""
 
     def __init__(
         self,
@@ -561,24 +615,24 @@ class TuningStep(ConfigurableRetryStep):
         depends_on: Union[List[str], List[Step]] = None,
         retry_policies: List[RetryPolicy] = None,
     ):
-        """Construct a TuningStep, given a `HyperparameterTuner` instance.
+        """Construct a `TuningStep`, given a `HyperparameterTuner` instance.
 
-        In addition to the tuner instance, the other arguments are those that are supplied to
-        the `fit` method of the `sagemaker.tuner.HyperparameterTuner`.
+        In addition to the `HyperparameterTuner` instance, the other arguments are those
+        that are supplied to the `fit` method of the `sagemaker.tuner.HyperparameterTuner`.
 
         Args:
-            name (str): The name of the tuning step.
+            name (str): The name of the `TuningStep`.
             tuner (HyperparameterTuner): A `sagemaker.tuner.HyperparameterTuner` instance.
-            display_name (str): The display name of the tuning step.
-            description (str): The description of the tuning step.
+            display_name (str): The display name of the `TuningStep`.
+            description (str): The description of the `TuningStep`.
             inputs: Information about the training data. Please refer to the
-                ``fit()`` method of the associated estimator, as this can take
+                `fit()` method of the associated estimator, as this can take
                 any of the following forms:
 
                 * (str) - The S3 location where training data is saved.
                 * (dict[str, str] or dict[str, sagemaker.inputs.TrainingInput]) -
                     If using multiple channels for training data, you can specify
-                    a dict mapping channel names to strings or
+                    a dictionary mapping channel names to strings or
                     :func:`~sagemaker.inputs.TrainingInput` objects.
                 * (sagemaker.inputs.TrainingInput) - Channel configuration for S3 data sources
                     that can provide additional information about the training dataset.
@@ -601,9 +655,9 @@ class TuningStep(ConfigurableRetryStep):
             job_arguments (List[str]): A list of strings to be passed into the processing job.
                 Defaults to `None`.
             cache_config (CacheConfig):  A `sagemaker.workflow.steps.CacheConfig` instance.
-            depends_on (List[str] or List[Step]): A list of step names or step instance
-                this `sagemaker.workflow.steps.ProcessingStep` depends on
-            retry_policies (List[RetryPolicy]):  A list of retry policy
+            depends_on (List[str] or List[Step]): A list of `Step` names or `Step` instances that
+                this `sagemaker.workflow.steps.ProcessingStep` depends on.
+            retry_policies (List[RetryPolicy]):  A list of retry policies.
         """
         super(TuningStep, self).__init__(
             name, StepTypeEnum.TUNING, display_name, description, depends_on, retry_policies
@@ -622,11 +676,11 @@ class TuningStep(ConfigurableRetryStep):
 
     @property
     def arguments(self) -> RequestType:
-        """The arguments dict that is used to call `create_hyper_parameter_tuning_job`.
+        """The arguments dictionary that is used to call `create_hyper_parameter_tuning_job`.
 
-        NOTE: The CreateHyperParameterTuningJob request is not quite the
+        NOTE: The `CreateHyperParameterTuningJob` request is not quite the
             args list that workflow needs.
-        The HyperParameterTuningJobName attribute cannot be included.
+        The `HyperParameterTuningJobName` attribute cannot be included.
         """
         if self.tuner.estimator is not None:
             self.tuner.estimator._prepare_for_training()
@@ -643,9 +697,9 @@ class TuningStep(ConfigurableRetryStep):
 
     @property
     def properties(self):
-        """A Properties object representing
+        """A `Properties` object
 
-        `DescribeHyperParameterTuningJobResponse` and
+        A `Properties` object representing `DescribeHyperParameterTuningJobResponse` and
         `ListTrainingJobsForHyperParameterTuningJobResponse` data model.
         """
         return self._properties
@@ -659,15 +713,15 @@ class TuningStep(ConfigurableRetryStep):
         return request_dict
 
     def get_top_model_s3_uri(self, top_k: int, s3_bucket: str, prefix: str = "") -> Join:
-        """Get the model artifact s3 uri from the top performing training jobs.
+        """Get the model artifact S3 URI from the top performing training jobs.
 
         Args:
-            top_k (int): the index of the top performing training job
-                tuning step stores up to 50 top performing training jobs, hence
-                a valid top_k value is from 0 to 49. The best training job
-                model is at index 0
-            s3_bucket (str): the s3 bucket to store the training job output artifact
-            prefix (str): the s3 key prefix to store the training job output artifact
+            top_k (int): The index of the top performing training job
+                tuning step stores up to 50 top performing training jobs.
+                A valid top_k value is from 0 to 49. The best training job
+                model is at index 0.
+            s3_bucket (str): The S3 bucket to store the training job output artifact.
+            prefix (str): The S3 key prefix to store the training job output artifact.
         """
         values = ["s3:/", s3_bucket]
         if prefix != "" and prefix is not None:
